@@ -17,8 +17,6 @@
  *
  */
 
-//go:generate deepcopy-gen -i . --go-header-file ../../../../hack/boilerplate/boilerplate.go.txt
-
 package api
 
 import (
@@ -264,7 +262,7 @@ type FeatureHyperv struct {
 	VPIndex         *FeatureState     `xml:"vpindex,omitempty"`
 	Runtime         *FeatureState     `xml:"runtime,omitempty"`
 	SyNIC           *FeatureState     `xml:"synic,omitempty"`
-	SyNICTimer      *FeatureState     `xml:"stimer,omitempty"`
+	SyNICTimer      *SyNICTimer       `xml:"stimer,omitempty"`
 	Reset           *FeatureState     `xml:"reset,omitempty"`
 	VendorID        *FeatureVendorID  `xml:"vendor_id,omitempty"`
 	Frequencies     *FeatureState     `xml:"frequencies,omitempty"`
@@ -279,6 +277,11 @@ type FeatureSpinlocks struct {
 	Retries *uint32 `xml:"retries,attr,omitempty"`
 }
 
+type SyNICTimer struct {
+	Direct *FeatureState `xml:"direct,omitempty"`
+	State  string        `xml:"state,attr,omitempty"`
+}
+
 type FeaturePVSpinlock struct {
 	State string `xml:"state,attr,omitempty"`
 }
@@ -450,6 +453,7 @@ type Input struct {
 
 // BEGIN HostDevice -----------------------------
 type HostDevice struct {
+	XMLName   xml.Name         `xml:"hostdev"`
 	Source    HostDeviceSource `xml:"source"`
 	Type      string           `xml:"type,attr"`
 	BootOrder *BootOrder       `xml:"boot,omitempty"`
@@ -504,6 +508,7 @@ type Disk struct {
 	BootOrder    *BootOrder    `xml:"boot,omitempty"`
 	Address      *Address      `xml:"address,omitempty"`
 	Model        string        `xml:"model,attr,omitempty"`
+	BlockIO      *BlockIO      `xml:"blockio,omitempty"`
 }
 
 type DiskAuth struct {
@@ -542,6 +547,7 @@ type DiskDriver struct {
 	Type        string `xml:"type,attr"`
 	IOThread    *uint  `xml:"iothread,attr,omitempty"`
 	Queues      *uint  `xml:"queues,attr,omitempty"`
+	Discard     string `xml:"discard,attr,omitempty"`
 }
 
 type DiskSourceHost struct {
@@ -559,6 +565,11 @@ type BackingStoreFormat struct {
 	Type string `xml:"type,attr"`
 }
 
+type BlockIO struct {
+	LogicalBlockSize  uint `xml:"logical_block_size,attr,omitempty"`
+	PhysicalBlockSize uint `xml:"physical_block_size,attr,omitempty"`
+}
+
 // END Disk -----------------------------
 
 // BEGIN Serial -----------------------------
